@@ -1,20 +1,9 @@
-// File_Mpeg_Descriptors - Info for MPEG files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about MPEG files, Descriptors
@@ -27,10 +16,12 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/Multiple/File_Mpeg4_Descriptors.h"
 #include "MediaInfo/Duplicate/File__Duplicate_MpegTs.h"
-#include <map>
+#if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+    #include "MediaInfo/File__Analyze.h"
+#endif
+#include <cfloat>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -59,8 +50,13 @@ struct complete_stream
         std::map<std::string, Ztring> Infos;
         struct program
         {
+            #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                File__Analyze::servicedescriptors* ServiceDescriptors;
+            #endif
             bool HasChanged;
             std::map<std::string, Ztring> Infos;
+            std::map<std::string, Ztring> ExtraInfos_Content;
+            std::map<std::string, Ztring> ExtraInfos_Option;
             std::map<Ztring, Ztring> EPGs;
             std::vector<int16u> elementary_PIDs;
             size_t StreamPos; //Stream_Menu
@@ -71,6 +67,7 @@ struct complete_stream
             bool   source_id_IsValid;
             bool   IsParsed;
             bool   IsRegistered;
+            bool   HasNotDisplayableStreams; //e.g. unknown stream, KLV, SCTE 35
             bool   Update_Needed_IsRegistered;
             bool   Update_Needed_StreamCount;
             bool   Update_Needed_StreamPos;
@@ -133,26 +130,109 @@ struct complete_stream
 
             //Constructor/Destructor
             program()
+            :
+                #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                    ServiceDescriptors(NULL),
+                #endif
+                HasChanged(false),
+                StreamPos((size_t)-1),
+                registration_format_identifier(0x00000000),
+                pid(0x00000),
+                PCR_PID(0x0000),
+                source_id((int16u)-1),
+                source_id_IsValid(false),
+                IsParsed(false),
+                IsRegistered(false),
+                HasNotDisplayableStreams(false),
+                Update_Needed_IsRegistered(false),
+                Update_Needed_StreamCount(false),
+                Update_Needed_StreamPos(false),
+                Update_Needed_Info(false),
+                DVB_EPG_Blocks_IsUpdated(false),
+                Scte35(NULL)
+            {}
+
+            program(const program& p)
+            :
+                HasChanged(p.HasChanged),
+                Infos(p.Infos),
+                ExtraInfos_Content(p.ExtraInfos_Content),
+                ExtraInfos_Option(p.ExtraInfos_Option),
+                EPGs(p.EPGs),
+                elementary_PIDs(p.elementary_PIDs),
+                StreamPos(p.StreamPos),
+                registration_format_identifier(p.registration_format_identifier),
+                pid(p.pid),
+                PCR_PID(p.PCR_PID),
+                source_id(p.source_id),
+                source_id_IsValid(p.source_id_IsValid),
+                IsParsed(p.IsParsed),
+                IsRegistered(p.IsRegistered),
+                HasNotDisplayableStreams(p.HasNotDisplayableStreams),
+                Update_Needed_IsRegistered(p.Update_Needed_IsRegistered),
+                Update_Needed_StreamCount(p.Update_Needed_StreamCount),
+                Update_Needed_StreamPos(p.Update_Needed_StreamPos),
+                Update_Needed_Info(p.Update_Needed_Info),
+                DVB_EPG_Blocks_IsUpdated(p.DVB_EPG_Blocks_IsUpdated),
+                Scte35(p.Scte35)
             {
-                HasChanged=false;
-                StreamPos=(size_t)-1;
-                registration_format_identifier=0x00000000;
-                pid=0x00000;
-                PCR_PID=0x0000;
-                source_id=(int16u)-1;
-                source_id_IsValid=false;
-                IsParsed=false;
-                IsRegistered=false;
-                Update_Needed_IsRegistered=false;
-                Update_Needed_StreamCount=false;
-                Update_Needed_StreamPos=false;
-                Update_Needed_Info=false;
-                DVB_EPG_Blocks_IsUpdated=false;
-                Scte35=NULL;
+                #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                    if (p.ServiceDescriptors)
+                    {
+                        ServiceDescriptors=new File__Analyze::servicedescriptors;
+                        *ServiceDescriptors=*p.ServiceDescriptors;
+                    }
+                    else
+                        ServiceDescriptors=NULL;
+                #endif
+            }
+
+            program& operator=(const program& p)
+            {
+                #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                    if (p.ServiceDescriptors)
+                    {
+                        ServiceDescriptors=new File__Analyze::servicedescriptors;
+                        *ServiceDescriptors=*p.ServiceDescriptors;
+                    }
+                    else
+                        ServiceDescriptors=NULL;
+                #endif
+                HasChanged=p.HasChanged;
+                Infos=p.Infos;
+                ExtraInfos_Content=p.ExtraInfos_Content;
+                ExtraInfos_Option=p.ExtraInfos_Option;
+                EPGs=p.EPGs;
+                elementary_PIDs=p.elementary_PIDs;
+                StreamPos=p.StreamPos;
+                registration_format_identifier=p.registration_format_identifier;
+                pid=p.pid;
+                PCR_PID=p.PCR_PID;
+                source_id=p.source_id;
+                source_id_IsValid=p.source_id_IsValid;
+                IsParsed=p.IsParsed;
+                IsRegistered=p.IsRegistered;
+                HasNotDisplayableStreams=p.HasNotDisplayableStreams;
+                Update_Needed_IsRegistered=p.Update_Needed_IsRegistered;
+                Update_Needed_StreamCount=p.Update_Needed_StreamCount;
+                Update_Needed_StreamPos=p.Update_Needed_StreamPos;
+                Update_Needed_Info=p.Update_Needed_Info;
+                DVB_EPG_Blocks_IsUpdated=p.DVB_EPG_Blocks_IsUpdated;
+                Scte35=p.Scte35;
+
+                return *this;
+            }
+
+            ~program()
+            {
+                #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                    delete ServiceDescriptors;
+                #endif
             }
         };
         typedef std::map<int16u, program> programs; //Key is program_number
         programs Programs; //Key is program_number
+        std::vector<int16u> programs_List;
         size_t   Programs_NotParsedCount;
 
         //Per IOD
@@ -232,7 +312,7 @@ struct complete_stream
         typedef std::vector<table_id*>              table_ids;
         table_ids                                   Table_IDs; //Key is table_id
         std::map<std::string, Ztring>               Infos;
-        std::map<int8u, Ztring>                     Languages; //Key is caption_service_number or 128+line21_field
+        std::map<std::string, Ztring>               Infos_Option;
         struct teletext
         {
             std::map<std::string, Ztring>           Infos;
@@ -255,14 +335,20 @@ struct complete_stream
             int64u                                  TimeStamp_End_Offset;
             int16u                                  PCR_PID; //If this pid has no PCR, decide which PCR should be used
             bool                                    TimeStamp_End_IsUpdated;
-            float64                                 TimeStamp_InstantaneousBitRate;
-            size_t                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsCbr;
-            size_t                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsVbr;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Min;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Raw;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Max;
+            int64u                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsCbr;
+            int64u                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsVbr;
             #if MEDIAINFO_ADVANCED
+                float64                             TimeStamp_InstantaneousBitRate_Min_Raw;
+                float64                             TimeStamp_InstantaneousBitRate_Max_Raw;
                 int64u                              TimeStamp_Distance_Min;
                 int64u                              TimeStamp_Distance_Max;
                 int64u                              TimeStamp_Distance_Total;
-                size_t                              TimeStamp_Distance_Count;
+                int64u                              TimeStamp_Distance_Count;
+                int64u                              TimeStamp_HasProblems;
+                std::vector<int64u>                 TimeStamp_Intermediate;
             #endif // MEDIAINFO_ADVANCED
         #endif //MEDIAINFO_MPEGTS_PCR_YES
         int32u                                      registration_format_identifier;
@@ -270,6 +356,7 @@ struct complete_stream
         int16u                                      table_type; //ATSC
         int8u                                       stream_type;
         int8u                                       descriptor_tag;
+        int8u                                       DtsNeural_config_id;
         bool                                        FMC_ES_ID_IsValid;
         bool                                        Searching;
         bool                                        Searching_Payload_Start;
@@ -288,12 +375,17 @@ struct complete_stream
         bool                                        IsUpdated_IsRegistered;
         bool                                        IsUpdated_Info;
         bool                                        CA_system_ID_MustSkipSlices;
+        bool                                        EBP_IsPresent;
         size_t                                      IsScrambled;
         int16u                                      CA_system_ID;
         int16u                                      SubStream_pid;
-        #if MEDIAINFO_IBI
+        #if MEDIAINFO_IBIUSAGE
             int64u                                  Ibi_SynchronizationOffset_BeginOfFrame;
-        #endif //MEDIAINFO_IBI
+        #endif //MEDIAINFO_IBIUSAGE
+        #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+            File__Analyze::servicedescriptors ServiceDescriptors;
+            bool                              ServiceDescriptors_IsPresent;
+        #endif
 
         //Constructor/Destructor
         stream()
@@ -313,14 +405,19 @@ struct complete_stream
                 TimeStamp_End_Offset=(int64u)-1;
                 PCR_PID=0x0000;
                 TimeStamp_End_IsUpdated=false;
-                TimeStamp_InstantaneousBitRate=0;
+                TimeStamp_InstantaneousBitRate_Current_Min=0;
+                TimeStamp_InstantaneousBitRate_Current_Raw=0;
+                TimeStamp_InstantaneousBitRate_Current_Max=0;
                 TimeStamp_InstantaneousBitRate_BitRateMode_IsCbr=0;
                 TimeStamp_InstantaneousBitRate_BitRateMode_IsVbr=0;
                 #if MEDIAINFO_ADVANCED
+                    TimeStamp_InstantaneousBitRate_Min_Raw=DBL_MAX;
+                    TimeStamp_InstantaneousBitRate_Max_Raw=0;
                     TimeStamp_Distance_Min=(int64u)-1;
                     TimeStamp_Distance_Max=0;
                     TimeStamp_Distance_Total=0;
                     TimeStamp_Distance_Count=0;
+                    TimeStamp_HasProblems=0;
                 #endif // MEDIAINFO_ADVANCED
             #endif //MEDIAINFO_MPEGTS_PCR_YES
             registration_format_identifier=0x00000000;
@@ -328,6 +425,7 @@ struct complete_stream
             table_type=0x0000;
             stream_type=(int8u)-1;
             descriptor_tag=(int8u)-1;
+            DtsNeural_config_id=(int8u)-1;
             FMC_ES_ID_IsValid=false;
             Searching=false;
             Searching_Payload_Start=false;
@@ -348,10 +446,14 @@ struct complete_stream
             IsScrambled=false;
             CA_system_ID_MustSkipSlices=false;
             CA_system_ID=0x0000;
+            EBP_IsPresent=false;
             SubStream_pid=0x0000;
-            #if MEDIAINFO_IBI
+            #if MEDIAINFO_IBIUSAGE
                 Ibi_SynchronizationOffset_BeginOfFrame=(int64u)-1;
-            #endif //MEDIAINFO_IBI
+            #endif //MEDIAINFO_IBIUSAGE
+            #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                ServiceDescriptors_IsPresent=false;
+            #endif
         }
 
         ~stream()
@@ -426,15 +528,58 @@ struct complete_stream
         {
             struct event
             {
+                #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                    File__Analyze::servicedescriptors* ServiceDescriptors;
+                #endif
                 int32u  start_time;
                 Ztring  duration;
                 Ztring  title;
-                std::map<int8u, Ztring>  Languages; //Key is caption_service_number or 128+line21_field
                 std::map<int16u, Ztring> texts;
 
                 event()
+                :
+                    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                        ServiceDescriptors(NULL),
+                    #endif
+                    start_time((int32u)-1)
+                {}
+
+                event(const event& e)
+                :
+                    start_time(e.start_time)
                 {
-                    start_time=(int32u)-1;
+                    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                        if (e.ServiceDescriptors)
+                        {
+                            ServiceDescriptors=new File__Analyze::servicedescriptors;
+                            *ServiceDescriptors=*e.ServiceDescriptors;
+                        }
+                        else
+                            ServiceDescriptors=NULL;
+                    #endif
+                }
+
+                event& operator=(const event& e)
+                {
+                    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                        if (e.ServiceDescriptors)
+                        {
+                            ServiceDescriptors=new File__Analyze::servicedescriptors;
+                            *ServiceDescriptors=*e.ServiceDescriptors;
+                        }
+                        else
+                            ServiceDescriptors=NULL;
+                    #endif
+                    start_time=e.start_time;
+
+                    return *this;
+                }
+
+                ~event()
+                {
+                    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+                        delete ServiceDescriptors;
+                    #endif
                 }
             };
 
@@ -489,6 +634,8 @@ struct complete_stream
         Programs_IsUpdated=false;
         NoPatPmt=false;
         StreamPos_ToRemove.resize(Stream_Max);
+        File__Duplicate_HasChanged_ = false;
+        Config_File_Duplicate_Get_AlwaysNeeded_Count = 0;
     }
 
     ~complete_stream()
@@ -500,7 +647,7 @@ struct complete_stream
         while (Duplicates_Temp!=Duplicates.end())
         {
             delete Duplicates_Temp->second; //Duplicates_Temp->second=NULL
-            Duplicates_Temp++;
+            ++Duplicates_Temp;
         }
     }
 };
@@ -535,6 +682,9 @@ public :
     File_Mpeg_Descriptors();
 
 private :
+    //Buffer - File header
+    void FileHeader_Parse();
+
     //Buffer - Per element
     void Header_Parse();
     void Data_Parse();
@@ -590,6 +740,18 @@ private :
     void Descriptor_2D() {Skip_XX(Element_Size, "Data");};
     void Descriptor_2E() {Skip_XX(Element_Size, "Data");};
     void Descriptor_2F();
+    void Descriptor_30() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_31() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_32() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_33() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_34() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_35() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_36() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_37() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_38() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_39() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_3A() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_3F() {Skip_XX(Element_Size, "Data");};
     void Descriptor_40();
     void Descriptor_41();
     void Descriptor_42() {Skip_XX(Element_Size, "Data");};
@@ -653,7 +815,8 @@ private :
     void Descriptor_7C();
     void Descriptor_7D() {Skip_XX(Element_Size, "Data");};
     void Descriptor_7E() {Skip_XX(Element_Size, "Data");};
-    void Descriptor_7F() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_7F();
+    void Descriptor_7F_0F();
     void Descriptor_80() {Skip_XX(Element_Size, "Data");};
     void Descriptor_81();
     void Descriptor_86();
@@ -666,6 +829,13 @@ private :
     void Descriptor_A9() {Skip_XX(Element_Size, "Data");};
     void Descriptor_AA();
     void Descriptor_AB() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_C1();
+    void Descriptor_C4() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_C8();
+    void Descriptor_DE();
+    void Descriptor_E9();
+    void Descriptor_FC();
+    void Descriptor_FD();
 
     //SCTE 35
     void CUEI_00();
